const OFF = 0
const ERROR = 2

module.exports = {
  plugins: [
    'react'
  ],
  parserOptions: {
    ecmaFeatures: {
      jsx: true
    }
  },
  rules: {
    'jsx-quotes': [ ERROR, 'prefer-double' ],
    'class-methods-use-this': [ ERROR, {
      exceptMethods: [
        'render',
        'getInitialState',
        'getDefaultProps',
        'getChildContext',
        'componentWillMount',
        'componentDidMount',
        'componentWillReceiveProps',
        'shouldComponentUpdate',
        'componentWillUpdate',
        'componentDidUpdate',
        'componentWillUnmount'
      ]
    } ],
    'react/display-name': [ OFF, { ignoreTranspilerName: false } ],
    'react/forbid-component-props': [ OFF, { forbid: [ 'className', 'style' ] } ],
    'react/forbid-prop-types': [ OFF, { forbid: [ 'any', 'array', 'object' ] } ],
    'react/no-children-prop': ERROR,
    'react/no-danger': OFF,
    'react/no-danger-with-children': OFF,
    'react/no-deprecated': [ ERROR ],
    'react/no-did-mount-set-state': [ ERROR ],
    'react/no-did-update-set-state': [ ERROR ],
    'react/no-direct-mutation-state': ERROR,
    'react/no-find-dom-node': ERROR,
    'react/no-is-mounted': ERROR,
    'react/no-multi-comp': [ ERROR, { ignoreStateless: true } ],
    'react/no-render-return-value': ERROR,
    'react/no-set-state': OFF,
    'react/no-string-refs': ERROR,
    'react/no-unescaped-entities': ERROR,
    'react/no-unknown-property': ERROR,
    'react/no-unused-prop-types': ERROR,
    'react/prefer-es6-class': [ ERROR, 'always' ],
    'react/prefer-stateless-function': [ ERROR, { ignorePureComponents: true } ],
    'react/prop-types': [ ERROR, { ignore: [], customValidators: [] } ],
    'react/react-in-jsx-scope': ERROR,
    'react/require-optimization': ERROR,
    'react/require-render-return': ERROR,
    'react/self-closing-comp': ERROR,
    'react/sort-comp': [ ERROR, {
      order: [
        'static-methods',
        'lifecycle',
        '/^on.+$/',
        '/^(get|set)(?!(InitialState$|DefaultProps$|ChildContext$)).+$/',
        'everything-else',
        '/^render.+$/',
        'render'
      ]
    } ],
    'react/sort-prop-types': [ OFF, {
      ignoreCase: true,
      callbacksLast: false
    } ],
    'react/style-prop-object': ERROR,
    'react/jsx-boolean-value': [ ERROR, 'never' ],
    'react/jsx-closing-bracket-location': [ ERROR, 'line-aligned' ],
    'react/jsx-curly-spacing': [ ERROR, 'never', { allowMultiline: true } ],
    'react/jsx-equals-spacing': [ ERROR, 'never' ],
    'react/jsx-filename-extension': OFF,
    'react/jsx-first-prop-new-line': [ ERROR, 'multiline' ],
    'react/jsx-handler-names': [ OFF, {
      eventHandlerPrefix: 'handle',
      eventHandlerPropPrefix: 'on'
    } ],
    'react/jsx-indent': [ ERROR, 2 ],
    'react/jsx-indent-props': [ ERROR, 2 ],
    'react/jsx-key': OFF,
    'react/jsx-max-props-per-line': [ OFF, { maximum: 1 } ],
    'react/jsx-no-bind': [ ERROR, {
      ignoreRefs: true,
      allowArrowFunctions: true,
      allowBind: false
    } ],
    'react/jsx-no-comment-textnodes': ERROR,
    'react/jsx-no-duplicate-props': [ ERROR, { ignoreCase: true } ],
    'react/jsx-no-literals': OFF,
    'react/jsx-no-target-blank': ERROR,
    'react/jsx-no-undef': ERROR,
    'react/jsx-pascal-case': [ ERROR, {
      allowAllCaps: true,
      ignore: []
    } ],
    'react/jsx-sort-props': [ OFF, {
      ignoreCase: true,
      callbacksLast: false
    } ],
    'react/jsx-space-before-closing': [ ERROR, 'always' ],
    'react/jsx-tag-spacing': [ ERROR, {
      closingSlash: 'never',
      beforeSelfClosing: 'always',
      afterOpening: 'never'
    } ],
    'react/jsx-uses-react': [ ERROR ],
    'react/jsx-uses-vars': ERROR,
    'react/jsx-wrap-multilines': [ ERROR, {
      declaration: true,
      assignment: true,
      return: true
    } ]
  },

  settings: {
    'import/resolver': {
      node: {
        extensions: [ '.js', '.jsx', '.json' ]
      }
    },
    react: {
      pragma: 'React',
      version: '15.3.0'
    }
  }
}
